@@ -181,15 +181,13 @@ class ExperimentConfig(metaclass=FrozenClassVariables):
     running the experiment.
     """
 
-    @classmethod
     @abc.abstractmethod
-    def tag(cls) -> str:
+    def tag(self) -> str:
         """A string describing the experiment."""
         raise NotImplementedError()
 
-    @classmethod
     @abc.abstractmethod
-    def training_pipeline(cls, **kwargs) -> TrainingPipeline:
+    def training_pipeline(self, **kwargs) -> TrainingPipeline:
         """Creates the training pipeline.
 
         # Parameters
@@ -202,10 +200,9 @@ class ExperimentConfig(metaclass=FrozenClassVariables):
         """
         raise NotImplementedError()
 
-    @classmethod
     @abc.abstractmethod
     def machine_params(
-        cls, mode="train", **kwargs
+        self, mode="train", **kwargs
     ) -> Union[MachineParams, Dict[str, Any]]:
         """Parameters used to specify machine information.
 
@@ -225,15 +222,13 @@ class ExperimentConfig(metaclass=FrozenClassVariables):
         """
         raise NotImplementedError()
 
-    @classmethod
     @abc.abstractmethod
-    def create_model(cls, **kwargs) -> nn.Module:
+    def create_model(self, **kwargs) -> nn.Module:
         """Create the neural model."""
         raise NotImplementedError()
 
-    @classmethod
     @abc.abstractmethod
-    def make_sampler_fn(cls, **kwargs) -> TaskSampler:
+    def make_sampler_fn(self, **kwargs) -> TaskSampler:
         """Create the TaskSampler given keyword arguments.
 
         These `kwargs` will be generated by one of
