@@ -18,6 +18,49 @@ Available log levels: "debug", "info", "warning", "error", "none"
 _LOGGER: Optional[logging.Logger] = None
 
 
+class ColoredFormatter(logging.Formatter):
+    """Format a log string with colors.
+
+    This implementation taken (with modifications) from
+    https://stackoverflow.com/a/384125.
+    """
+
+    BLACK, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE = range(8)
+
+    RESET_SEQ = "\033[0m"
+    COLOR_SEQ = "\033[1;%dm"
+    BOLD_SEQ = "\033[1m"
+
+    COLORS = {
+        "WARNING": YELLOW,
+        "INFO": GREEN,
+        "DEBUG": BLUE,
+        "ERROR": RED,
+        "CRITICAL": MAGENTA,
+    }
+
+    def __init__(self, fmt: str, datefmt: Optional[str] = None, use_color=True):
+        super().__init__(fmt=fmt, datefmt=datefmt)
+        self.use_color = use_color
+
+    def format(self, record: logging.LogRecord) -> str:
+        levelname = record.levelname
+        if self.use_color and levelname in self.COLORS:
+            levelname_with_color = (
+                self.COLOR_SEQ % (30 + self.COLORS[levelname])
+                + levelname
+                + self.RESET_SEQ
+            )
+            record.levelname = levelname_with_color
+            formated_record = logging.Formatter.format(self, record)
+            record.levelname = (
+                levelname  # Resetting levelname as `record` might be used elsewhere
+            )
+            return formated_record
+        else:
+            return logging.Formatter.format(self, record)
+
+
 def get_logger() -> logging.Logger:
     """Get a `logging.Logger` to stderr. It can be called whenever we wish to
     log some message. Messages can get mixed-up
@@ -93,23 +136,36 @@ def _set_log_formatter():
     assert _LOGGER is not None
 
     if _LOGGER.getEffectiveLevel() <= logging.CRITICAL:
-        default_format = (
-            "%(asctime)s %(levelname)s: %(message)s\t[%(filename)s: %(lineno)d]"
-        )
+        add_style_to_logs = True  # In case someone wants to turn this off manually.
+
+        if add_style_to_logs:
+            default_format = "$BOLD[%(asctime)s$RESET %(levelname)s$BOLD:]$RESET %(message)s\t[%(filename)s: %(lineno)d]"
+            default_format = default_format.replace(
+                "$BOLD", ColoredFormatter.BOLD_SEQ
+            ).replace("$RESET", ColoredFormatter.RESET_SEQ)
+        else:
+            default_format = (
+                "%(asctime)s %(levelname)s: %(message)s\t[%(filename)s: %(lineno)d]"
+            )
         short_date_format = "%m/%d %H:%M:%S"
         log_format = "default"
 
-        ch = logging.StreamHandler()
-
         if log_format == "default":
-            formatter = logging.Formatter(
-                fmt=default_format, datefmt=short_date_format,
-            )
+            fmt = default_format
+            datefmt = short_date_format
         elif log_format == "defaultMilliseconds":
-            formatter = logging.Formatter(fmt=default_format)
+            fmt = default_format
+            datefmt = None
         else:
-            formatter = logging.Formatter(fmt=log_format, datefmt=short_date_format)
+            fmt = log_format
+            datefmt = short_date_format
 
+        if add_style_to_logs:
+            formatter = ColoredFormatter(fmt=fmt, datefmt=datefmt,)
+        else:
+            formatter = logging.Formatter(fmt=fmt, datefmt=datefmt)
+
+        ch = logging.StreamHandler()
         ch.setFormatter(formatter)
         ch.addFilter(cast(logging.Filter, _AllenActMessageFilter(os.getcwd())))
         _LOGGER.addHandler(ch)
